#
# spec file for package perl-File-ShareDir
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-File-ShareDir
Version:        1.118
Release:        1.17
%define cpan_name File-ShareDir
Summary:        Locate per-dist and per-module shared files
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RE/REHSACK/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Class::Inspector) >= 1.12
BuildRequires:  perl(File::Path) >= 2.080000
BuildRequires:  perl(Test::More) >= 0.90
Requires:       perl(Class::Inspector) >= 1.12
Recommends:     perl(List::MoreUtils) >= 0.428
Recommends:     perl(Params::Util) >= 1.07
%{perl_requires}
# MANUAL BEGIN
# because File::ShareDir::Install is in inc/ it won't be seen as a
# dependency by cpanspec
BuildRequires:  perl(File::ShareDir::Install)
# MANUAL END

%description
The intent of File::ShareDir is to provide a companion to Class::Inspector
and File::HomeDir, modules that take a process that is well-known by
advanced Perl developers but gets a little tricky, and make it more
available to the larger Perl community.

Quite often you want or need your Perl module (CPAN or otherwise) to have
access to a large amount of read-only data that is stored on the
file-system at run-time.

On a linux-like system, this would be in a place such as /usr/share,
however Perl runs on a wide variety of different systems, and so the use of
any one location is unreliable.

Perl provides a little-known method for doing this, but almost nobody is
aware that it exists. As a result, module authors often go through some
very strange ways to make the data available to their code.

The most common of these is to dump the data out to an enormous Perl data
structure and save it into the module itself. The result are enormous
multi-megabyte .pm files that chew up a lot of memory needlessly.

Another method is to put the data "file" after the __DATA__ compiler tag
and limit yourself to access as a filehandle.

The problem to solve is really quite simple.

  1. Write the data files to the system at install time.
  
  2. Know where you put them at run-time.

Perl's install system creates an "auto" directory for both every
distribution and for every module file.

These are used by a couple of different auto-loading systems to store code
fragments generated at install time, and various other modules written by
the Perl "ancient masters".

But the same mechanism is available to any dist or module to store any sort
of data.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README.md testrules.yml
%license LICENSE

%changelog
* Thu Oct 22 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.118
  see /usr/share/doc/packages/perl-File-ShareDir/Changes
  1.118	2020-10-21
  - Releasing 1.117_001 without further changes
  1.117_001	2020-09-25
  - fix failing test of dependencies after in 1.116 (from 1.112),
    thanks to Dirk Stöcker for reporting via RT#127376 and
    Mohammad S Anwar (@manwar) for providing the fix via Github
    PR#14
  - Fix RT#133368 (PR#15): Fix running tests in parallel submitted
    by Kent Fredric (KENTNL) and fix provided by Tom Hukins (@tomhukins)
  - Fix RT#125907: spelling error in manpage - thanks to Lucas Kanashiro
    for reporting and Graham Knop (@haarg) for kicking me by submitting
    PR#17
* Tue Oct 22 2019 Tina Mueller <tina.mueller@suse.com>
- Add manual dependency File::ShareDir::Install
  * The module delivers a version of this in inc/, but doesn't use this
    in the tests. cpanspec won't detect this as a dependency
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.116
  see /usr/share/doc/packages/perl-File-ShareDir/Changes
  1.116	2018-06-24
  - fix fail-test which incorrectly read without permission
    ==> introduce new CI test proving this (Thanks to Ville
    Skyttä <ville.skytta@iki.fi>)
  - spelling fixes (Thanks to Ville Skyttä <ville.skytta@iki.fi>)
  - fix author tests when run without recommended dependencies
    (reported by Mohammed Anwar & Wesley Schwengle)
  - add a test proving and reporting dependencies
  1.114	2018-06-21
  - be more expressive regarding to prerequisites
  - improve detection for situations where no permission test
    can be done
  - fix edge case for 5.8
* Tue Jun 19 2018 coolo@suse.com
- updated to 1.112
  see /usr/share/doc/packages/perl-File-ShareDir/Changes
  1.112	2018-06-18
  - Fix tests that fail when running as root (RT#125602,
    thanks Wesley Schwengle <wesley@schwengle.net>)
  - Fix tests fail on MSWin32 for similar reason as the
    root failures from RT#125602
  - clarify support rules
  - improve POD
  1.110	2018-06-16
  - remove unused/incomplete _dist_packfile
  - increase test coverage
  - refactor _search_inc_path
  - add badges to POD
* Sat Jun 16 2018 coolo@suse.com
- updated to 1.108
  see /usr/share/doc/packages/perl-File-ShareDir/Changes
  1.108	2018-06-15
  - Fix RT#125582: Undefined subroutine &File::ShareDir::croak
    called reported by yseto and Andreas Koenig (via RT#125575)
  - Improve tests a little (a higher test coverage would be great)
  - Update README.md
* Mon Jun 11 2018 coolo@suse.com
- updated to 1.106
  see /usr/share/doc/packages/perl-File-ShareDir/Changes
  1.106	2018-06-10
  - Add support for overriding the resolved path for a given
    Module or Dist (Thanks to Kent Fredric <kentnl@cpan.org>)
  - Fix RT#84914: _dist_file_new lacks return check (Thanks to
    Alex Peters <lxp@cpan.org>) -- fixes RT#40158, too.
  - Fix RT#60431: common @INC traversal code
    Phillip Moore <w.phillip.moore@gmail.com> requested for
    easier overriding in controlled environments an extraction
    of @INC traversal in one subroutine.
    The provided patch has been applied with minor modifications,
    thanks Phillip!
  - Fix RT#63548: State explicit how developers can use
    File::ShareDir even in development phase out-of-the-box
  - Fix RT#18042: Windows style path errors (Thanks to Barbie
    <barbie@missbarbell.co.uk>)
  - Improve infrastructure of distribution (toolchain, perltidy,
    perlcritic, Devel::Cover, ...)
  - deploy with most recent File::ShareDir::Install (v0.12-6-g29a6ff7
    aka 0.13)
* Fri Jun 30 2017 coolo@suse.com
- updated to 1.104
  see /usr/share/doc/packages/perl-File-ShareDir/Changes
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.102
  see /usr/share/doc/packages/perl-File-ShareDir/Changes
* Fri Nov 18 2011 coolo@suse.com
- update to 1.03
  - Upgraded to Module::Install 1.00
* Tue Nov 30 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Sun Nov 28 2010 coolo@novell.com
- remove .packlist file
* Sun Mar 21 2010 lars@linux-schulserver.de
- update to 1.02:
  + Upgraded to Module::Install 0.95
  + Removed Params::Util dep
- removed dependency to perl-Params-Util package
* Sat Dec 26 2009 lars@linux-schulserver.de
- initial version 1.01
